@@ -24,26 +24,37 @@ class TestDict(test.TestCase):
     self.assertEqual({}, self.testee.backend.dump())
     
     for _ in range(4):
-      self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
+      self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', b = 'beta'))
       self.assertEqual(1, self.fixture.calls)
       self.assertEqual({
-        'cache:entry:Fixture:simple:109cc9a8853ebcb1' : 'ateb+ahpla'
+        'cache:entry:Fixture:simple:' + self._arghash('alpha', b = 'beta') : 'ateb+ahpla'
       }, self.testee.backend.dump())
     
-    self.fixture.simple.invalidate('alpha', 'beta')
+    self.fixture.simple.invalidate('alpha', b = 'beta')
     self.assertEqual({}, self.testee.backend.dump())
 
     
     self.assertEqual(1,  self.fixture.calls)
     self.assertEqual({}, self.testee.backend.dump())
     
-    expected = "])]'ammag'[(tes[+}]'ateb'[ :'ahpla'{"
+    expectedPy2 = "])]'ammag'[(tes[+}]'ateb'[ :'ahpla'{"
+    expectedPy3 = "]}'ammag'{[+}]'ateb'[ :'ahpla'{"
     for _ in range(4):
-      self.assertEqual(expected, self.fixture.simple({'alpha' : ['beta']}, [{'gamma'}]))
+      try:
+        self.assertEqual(expectedPy2, self.fixture.simple({'alpha' : ['beta']}, [{'gamma'}]))
+      except AssertionError:
+        self.assertEqual(expectedPy3, self.fixture.simple({'alpha' : ['beta']}, [{'gamma'}]))
+        
       self.assertEqual(2, self.fixture.calls)
-      self.assertEqual({
-        'cache:entry:Fixture:simple:1791fb72b0c00b29' : expected
-      }, self.testee.backend.dump())
+      expected = {
+        'cache:entry:Fixture:simple:' + self._arghash({'alpha' : ['beta']}, [{'gamma'}]) : expectedPy2
+      }
+      try:
+        self.assertEqual(expected, self.testee.backend.dump())
+      except AssertionError:
+        expected[tuple(expected.keys())[0]] = expectedPy3
+        self.assertEqual(expected, self.testee.backend.dump())
+        
     
     self.fixture.simple.invalidate({'alpha' : ['beta']}, [{'gamma'}])
     self.assertEqual({}, self.testee.backend.dump())
@@ -53,7 +64,7 @@ class TestDict(test.TestCase):
     self.assertEqual({}, self.testee.backend.dump())
     
     for _ in range(4):
-      self.assertEqual('ae-hl', self.fixture.tagged('alpha', 'beta'))
+      self.assertEqual('ae-hl', self.fixture.tagged('alpha', b = 'beta'))
       self.assertEqual(1,       self.fixture.calls)
       
       cache = self.testee.backend.dump()
@@ -61,12 +72,12 @@ class TestDict(test.TestCase):
       self.assertEqual(16, len(cache.pop('cache:tag:rock')))
       self.assertEqual(16, len(cache.pop('cache:tag:tree')))
       
-      expected = 'cache:entry:Fixture:tagged:109cc9a8853ebcb1'
-      self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual('ae-hl', cache.values()[0])
+      expected = 'cache:entry:Fixture:tagged:' + self._arghash('alpha', b = 'beta')
+      self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual('ae-hl', tuple(cache.values())[0])
     
     
-    self.fixture.tagged.invalidate('alpha', 'beta')
+    self.fixture.tagged.invalidate('alpha', b = 'beta')
     
     cache = self.testee.backend.dump()
     self.assertEqual(2, len(cache))
@@ -82,7 +93,7 @@ class TestDict(test.TestCase):
       self.assertEqual(3, self.fixture.calls)
       
       cache = self.testee.backend.dump()
-      self.assertEqual(5,  len(cache))
+      self.assertEqual(5, len(cache))
       self.assertEqual(rockTag, cache.get('cache:tag:rock'))
       self.assertEqual(treeTag, cache.get('cache:tag:tree'))
       self.assertEqual(16, len(cache.get('cache:tag:ice')))
@@ -127,7 +138,10 @@ class TestDict(test.TestCase):
     for _ in range(4):
       self.assertEqual('ateb+ahpla', foo('alpha', 'beta'))
       self.assertEqual(1, counter['foo'])
-      self.assertEqual({'cache:entry:foo:109cc9a8853ebcb1' : 'ateb+ahpla'}, self.testee.backend.dump())
+      self.assertEqual(
+        {'cache:entry:foo:' + self._arghash('alpha', 'beta') : 'ateb+ahpla'}, 
+        self.testee.backend.dump()
+      )
     
     foo.invalidate('alpha', 'beta')
     self.assertEqual(1,  counter['foo'])
@@ -147,8 +161,8 @@ class TestDict(test.TestCase):
       self.assertEqual(16, len(cache.pop('cache:tag:z')))
       
       expected = 'mk:alpha:beta'
-      self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual('apabt', cache.values()[0])
+      self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual('apabt', tuple(cache.values())[0])
     
     bar.invalidate('alpha', 'beta')
     self.assertEqual(1, counter['foo'])
@@ -172,8 +186,8 @@ class TestDict(test.TestCase):
       self.assertEqual(16, len(cache.pop('cache:tag:stone')))
       
       expected = 'mykey:alpha:beta'
-      self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual('apabt', cache.values()[0])
+      self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual('apabt', tuple(cache.values())[0])
     
     self.fixture.key.invalidate('alpha', 'beta')
     
@@ -196,8 +210,8 @@ class TestDict(test.TestCase):
       self.assertEqual(16, len(cache.pop('cache:tag:z')))
       
       expected = "mk:{'alpha':1}:['beta']"
-      self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual({'a': 1, 'b': {'b': 'beta'}}, cache.values()[0])
+      self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual({'a': 1, 'b': {'b': 'beta'}}, tuple(cache.values())[0])
     
     self.fixture.all.invalidate({'alpha' : 1}, ['beta'])
     
@@ -229,26 +243,27 @@ class TestDict(test.TestCase):
     
     cache = self.testee.backend.dump()
     self.assertEqual(4, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:109cc9a8853ebcb1'))
+    
+    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:' + self._arghash('alpha', 'beta')))
     self.assertEqual(16, len(cache.pop('cache:tag:rock')))
     self.assertEqual(16, len(cache.pop('cache:tag:tree')))
     
-    expected = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb'
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    expectedKey = 'cache:entry:Fixture:tagged:' + self._arghash('gamma', 'delta')
+    self.assertEqual(expectedKey, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.testee.clean(('rock',))
     
     cache = self.testee.backend.dump()
     self.assertEqual(3, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:109cc9a8853ebcb1'))
+    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:' + self._arghash('alpha', 'beta')))
     self.assertEqual(16, len(cache.pop('cache:tag:tree')))
     self.assertFalse('cache:tag:rock' in cache)
     
-    expected = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb'
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    expectedKey = 'cache:entry:Fixture:tagged:' + self._arghash('gamma', 'delta')
+    self.assertEqual(expectedKey, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
 
     
     self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
@@ -257,26 +272,26 @@ class TestDict(test.TestCase):
     
     cache = self.testee.backend.dump()
     self.assertEqual(5, len(cache), '+1 old tagged entry')
-    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:109cc9a8853ebcb1'))
+    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:' + self._arghash('alpha', 'beta')))
     self.assertEqual(16, len(cache.pop('cache:tag:rock')))
     self.assertEqual(16, len(cache.pop('cache:tag:tree')))
     
-    expected = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb'
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    expectedKey = 'cache:entry:Fixture:tagged:' + self._arghash('gamma', 'delta')
+    self.assertEqual(expectedKey, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.testee.clean(('rock', 'tree'))
     
     cache = self.testee.backend.dump()
     self.assertEqual(3, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:109cc9a8853ebcb1'))
+    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:' + self._arghash('alpha', 'beta')))
     self.assertFalse('cache:tag:tree' in cache)
     self.assertFalse('cache:tag:rock' in cache)
     
-    expected = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb'
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    expectedKey = 'cache:entry:Fixture:tagged:' + self._arghash('gamma', 'delta')
+    self.assertEqual(expectedKey, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
@@ -285,13 +300,10 @@ class TestDict(test.TestCase):
     
     cache = self.testee.backend.dump()
     self.assertEqual(6, len(cache), '+2 old tagged entries')
-    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:109cc9a8853ebcb1'))
-    self.assertEqual(16, len(cache.pop('cache:tag:rock')))
-    self.assertEqual(16, len(cache.pop('cache:tag:tree')))
-    
-    expected = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb'
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    self.assertEqual('ateb+ahpla', cache.pop('cache:entry:Fixture:simple:' + self._arghash('alpha', 'beta')))
+    expectedKey = 'cache:entry:Fixture:tagged:' + self._arghash('gamma', 'delta')
+    self.assertTrue(expectedKey in (':'.join(k.split(':')[:-1]) for k in cache.keys()))
+    self.assertTrue('aldamg' in cache.values())
     
     
     self.testee.clean()
@@ -303,8 +315,8 @@ class TestDict(test.TestCase):
     self.assertEqual('beta+alpha', self.fixture.nested('alpha', 'beta'))
     self.assertEqual(2, self.fixture.calls)
     self.assertEqual({
-      'cache:entry:Fixture:nested:109cc9a8853ebcb1': 'beta+alpha', 
-      'cache:entry:Fixture:simple:304d56b9ab021ab2': 'ahpla+ateb'
+      'cache:entry:Fixture:nested:' + self._arghash('alpha', 'beta') : 'beta+alpha', 
+      'cache:entry:Fixture:simple:' + self._arghash('beta', 'alpha') : 'ahpla+ateb'
     }, self.testee.backend.dump())
     
   def testConcurrent(self):
@@ -316,9 +328,9 @@ class TestDict(test.TestCase):
       time.sleep(0.04)
       return '{0}-{1}'.format(a, b)[::2]
     
-    threads = map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertEqual(1, sum(log))
     
@@ -326,16 +338,16 @@ class TestDict(test.TestCase):
     self.assertEqual(16, len(cache.pop('cache:tag:a')))
     self.assertEqual(16, len(cache.pop('cache:tag:z')))
     
-    self.assertEqual('mk:alpha:beta', ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('apabt', cache.values()[0])
+    self.assertEqual('mk:alpha:beta', ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('apabt', tuple(cache.values())[0])
     
     del log[:]
     self.testee.clean()
     self.testee.backend.lock = lambda k: hermes.backend.AbstractLock(k) # now see a dogpile 
     
-    threads = map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertGreater(sum(log), 1, 'dogpile')
     
@@ -343,8 +355,8 @@ class TestDict(test.TestCase):
     self.assertEqual(16, len(cache.pop('cache:tag:a')))
     self.assertEqual(16, len(cache.pop('cache:tag:z')))
     
-    self.assertEqual('mk:alpha:beta', ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('apabt', cache.values()[0])
+    self.assertEqual('mk:alpha:beta', ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('apabt', tuple(cache.values())[0])
 
 
 class TestDictLock(test.TestCase):
@@ -382,9 +394,9 @@ class TestDictLock(test.TestCase):
         check.release()
         time.sleep(0.05)
     
-    threads = map(lambda i: threading.Thread(target = target), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = target), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertEqual([True] * 4, log)
 
@@ -413,6 +425,14 @@ class TestDictCustomMangler(TestDict):
     
     self.testee.clean()
   
+  def _arghash(self, *args, **kwargs):
+    '''Not very neat as it penetrates into an implementation detail, though otherwise it'll 
+    be harder to make assertion on keys, because hash results are different on py2 and py3
+    and their 32/64-bit builds'''
+    
+    arguments = args, tuple(sorted(kwargs.items()))
+    return hash(json.dumps(arguments))
+  
   def testSimple(self):
     self.assertEqual(0,  self.fixture.calls)
     self.assertEqual({}, self.testee.backend.dump())
@@ -421,7 +441,7 @@ class TestDictCustomMangler(TestDict):
       self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
       self.assertEqual(1, self.fixture.calls)
       self.assertEqual({
-        'hermes:entry:Fixture:simple:5498827398669242949' : 'ateb+ahpla'
+        'hermes:entry:Fixture:simple:' + str(self._arghash('alpha', 'beta')) : 'ateb+ahpla'
       }, self.testee.backend.dump())
     
     self.fixture.simple.invalidate('alpha', 'beta')
@@ -435,9 +455,8 @@ class TestDictCustomMangler(TestDict):
     for _ in range(4):
       self.assertEqual(expected, self.fixture.simple({'alpha' : ['beta']}, [{'gamma' : 'delta'}]))
       self.assertEqual(2, self.fixture.calls)
-      self.assertEqual({
-        'hermes:entry:Fixture:simple:-1807113385712696284' : expected
-      }, self.testee.backend.dump())
+      argHash = str(self._arghash({'alpha' : ['beta']}, [{'gamma' : 'delta'}]))
+      self.assertEqual({'hermes:entry:Fixture:simple:' + argHash : expected}, self.testee.backend.dump())
     
     self.fixture.simple.invalidate({'alpha' : ['beta']}, [{'gamma' : 'delta'}])
     self.assertEqual({}, self.testee.backend.dump())
@@ -456,9 +475,9 @@ class TestDictCustomMangler(TestDict):
       self.assertTrue(int(cache.pop('hermes:tag:rock')) != 0)
       self.assertTrue(int(cache.pop('hermes:tag:tree')) != 0)
       
-      expected = 'hermes:entry:Fixture:tagged:5498827398669242949'
-      self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual('ae-hl', cache.values()[0])
+      expected = 'hermes:entry:Fixture:tagged:' + str(self._arghash('alpha', 'beta'))
+      self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual('ae-hl', tuple(cache.values())[0])
     
     self.fixture.tagged.invalidate('alpha', 'beta')
     
@@ -521,7 +540,8 @@ class TestDictCustomMangler(TestDict):
     for _ in range(4):
       self.assertEqual('ateb+ahpla', foo('alpha', 'beta'))
       self.assertEqual(1, counter['foo'])
-      self.assertEqual({'hermes:entry:foo:5498827398669242949' : 'ateb+ahpla'}, self.testee.backend.dump())
+      argHash = self._arghash('alpha', 'beta')
+      self.assertEqual({'hermes:entry:foo:' + str(argHash) : 'ateb+ahpla'}, self.testee.backend.dump())
     
     foo.invalidate('alpha', 'beta')
     self.assertEqual(1,  counter['foo'])
@@ -540,8 +560,8 @@ class TestDictCustomMangler(TestDict):
       self.assertTrue(int(cache.pop('hermes:tag:a')) != 0)
       self.assertTrue(int(cache.pop('hermes:tag:z')) != 0)
       
-      self.assertEqual('mk:alpha:beta', ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual('apabt', cache.values()[0])
+      self.assertEqual('mk:alpha:beta', ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual('apabt', tuple(cache.values())[0])
     
     bar.invalidate('alpha', 'beta')
     
@@ -566,8 +586,8 @@ class TestDictCustomMangler(TestDict):
       self.assertTrue(int(cache.pop('hermes:tag:ash')) != 0)
       self.assertTrue(int(cache.pop('hermes:tag:stone')) != 0)
       
-      self.assertEqual('mykey:alpha:beta', ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual('apabt', cache.values()[0])
+      self.assertEqual('mykey:alpha:beta', ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual('apabt', tuple(cache.values())[0])
     
     self.fixture.key.invalidate('alpha', 'beta')
     
@@ -590,8 +610,8 @@ class TestDictCustomMangler(TestDict):
       self.assertTrue(int(cache.pop('hermes:tag:z')) != 0)
       
       expected = "mk:{'alpha':1}:['beta']"
-      self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-      self.assertEqual({'a': 1, 'b': {'b': 'beta'}}, cache.values()[0])
+      self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+      self.assertEqual({'a': 1, 'b': {'b': 'beta'}}, tuple(cache.values())[0])
     
     self.fixture.all.invalidate({'alpha' : 1}, ['beta'])
     
@@ -623,26 +643,26 @@ class TestDictCustomMangler(TestDict):
     
     cache = self.testee.backend.dump()
     self.assertTrue(4, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:5498827398669242949'))
+    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:' + str(self._arghash('alpha', 'beta'))))
     self.assertFalse(cache.get('hermes:tag:tree') == cache.get('hermes:tag:rock'))
     self.assertTrue(int(cache.pop('hermes:tag:rock')) != 0)
     self.assertTrue(int(cache.pop('hermes:tag:tree')) != 0)
     
-    expected = 'hermes:entry:Fixture:tagged:3606254630768090685'
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    expected = 'hermes:entry:Fixture:tagged:' + str(self._arghash('gamma', 'delta'))
+    self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.testee.clean(('rock',))
     
     cache = self.testee.backend.dump()
     self.assertTrue(3, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:5498827398669242949'))
+    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:' + str(self._arghash('alpha', 'beta'))))
     self.assertTrue(int(cache.pop('hermes:tag:tree')) != 0)
     self.assertFalse('hermes:tag:rock' in cache)
     
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
 
     
     self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
@@ -651,25 +671,25 @@ class TestDictCustomMangler(TestDict):
     
     cache = self.testee.backend.dump()
     self.assertTrue(4, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:5498827398669242949'))
+    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:' + str(self._arghash('alpha', 'beta'))))
     self.assertFalse(cache.get('hermes:tag:tree') == cache.get('hermes:tag:rock'))
     self.assertTrue(int(cache.pop('hermes:tag:rock')) != 0)
     self.assertTrue(int(cache.pop('hermes:tag:tree')) != 0)
     
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.testee.clean(('rock', 'tree'))
     
     cache = self.testee.backend.dump()
     self.assertTrue(2, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:5498827398669242949'))
+    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:' + str(self._arghash('alpha', 'beta'))))
     self.assertFalse('hermes:tag:tree' in cache)
     self.assertFalse('hermes:tag:rock' in cache)
     
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
@@ -678,13 +698,13 @@ class TestDictCustomMangler(TestDict):
     
     cache = self.testee.backend.dump()
     self.assertTrue(4, len(cache))
-    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:5498827398669242949'))
+    self.assertEqual('ateb+ahpla', cache.pop('hermes:entry:Fixture:simple:' + str(self._arghash('alpha', 'beta'))))
     self.assertFalse(cache.get('hermes:tag:tree') == cache.get('hermes:tag:rock'))
     self.assertTrue(int(cache.pop('hermes:tag:rock')) != 0)
     self.assertTrue(int(cache.pop('hermes:tag:tree')) != 0)
     
-    self.assertEqual(expected, ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('aldamg', cache.values()[0])
+    self.assertEqual(expected, ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('aldamg', tuple(cache.values())[0])
     
     
     self.testee.clean()
@@ -696,8 +716,8 @@ class TestDictCustomMangler(TestDict):
     self.assertEqual('beta+alpha', self.fixture.nested('alpha', 'beta'))
     self.assertEqual(2, self.fixture.calls)
     self.assertEqual({
-      'hermes:entry:Fixture:nested:5498827398669242949': 'beta+alpha', 
-      'hermes:entry:Fixture:simple:-4144140260472190711': 'ahpla+ateb'
+      'hermes:entry:Fixture:nested:' + str(self._arghash('alpha', 'beta')) : 'beta+alpha', 
+      'hermes:entry:Fixture:simple:' + str(self._arghash('beta', 'alpha')) : 'ahpla+ateb'
     }, self.testee.backend.dump())
     
   def testConcurrent(self):
@@ -709,9 +729,9 @@ class TestDictCustomMangler(TestDict):
       time.sleep(0.04)
       return '{0}-{1}'.format(a, b)[::2]
     
-    threads = map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertEqual(1, sum(log))
     
@@ -719,16 +739,16 @@ class TestDictCustomMangler(TestDict):
     self.assertTrue(int(cache.pop('hermes:tag:a')) != 0)
     self.assertTrue(int(cache.pop('hermes:tag:z')) != 0)
     
-    self.assertEqual('mk:alpha:beta', ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('apabt', cache.values()[0])
+    self.assertEqual('mk:alpha:beta', ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('apabt', tuple(cache.values())[0])
     
     del log[:]
     self.testee.clean()
     self.testee.backend.lock = lambda k: hermes.backend.AbstractLock(k) # now see a dogpile 
     
-    threads = map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertGreater(sum(log), 1, 'dogpile')
     
@@ -736,5 +756,6 @@ class TestDictCustomMangler(TestDict):
     self.assertTrue(int(cache.pop('hermes:tag:a')) != 0)
     self.assertTrue(int(cache.pop('hermes:tag:z')) != 0)
     
-    self.assertEqual('mk:alpha:beta', ':'.join(cache.keys()[0].split(':')[:-1]))
-    self.assertEqual('apabt', cache.values()[0])
+    self.assertEqual('mk:alpha:beta', ':'.join(tuple(cache.keys())[0].split(':')[:-1]))
+    self.assertEqual('apabt', tuple(cache.values())[0])
+
