@@ -23,39 +23,47 @@ class TestMemcached(test.TestCase):
     self.testee.clean()
   
   def getSize(self):
-    return int(self.testee.backend.client.get_stats()[0][1]['curr_items'])
+    return int(self.testee.backend.client.get_stats()[0][1][b'curr_items'])
   
   def testSimple(self):
     self.assertEqual(0, self.fixture.calls)
     self.assertEqual(0, self.getSize())
 
-    key = 'cache:entry:Fixture:simple:109cc9a8853ebcb1'
+    key = 'cache:entry:Fixture:simple:' + self._arghash('alpha', b = 'beta')
     for _ in range(4):
-      self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', 'beta'))
+      self.assertEqual('ateb+ahpla', self.fixture.simple('alpha', b = 'beta'))
       self.assertEqual(1, self.fixture.calls)
       self.assertEqual(1, self.getSize())
   
       self.assertEqual('ateb+ahpla', pickle.loads(self.testee.backend.client.get(key)))
     
-    self.fixture.simple.invalidate('alpha', 'beta')
+    self.fixture.simple.invalidate('alpha', b = 'beta')
     self.assertEqual(0, self.getSize())
     
     
-    expected = "])]'ammag'[(tes[+}]'ateb'[ :'ahpla'{"
-    key      = 'cache:entry:Fixture:simple:1791fb72b0c00b29'
-    for _ in range(4): 
-      self.assertEqual(expected, self.fixture.simple({'alpha' : ['beta']}, [{'gamma'}]))
+    expectedPy2 = "])]'ammag'[(tes[+}]'ateb'[ :'ahpla'{"
+    expectedPy3 = "]}'ammag'{[+}]'ateb'[ :'ahpla'{"
+    key      = 'cache:entry:Fixture:simple:' + self._arghash({'alpha' : ['beta']}, [{'gamma'}])
+    for _ in range(4):
+      try: 
+        self.assertEqual(expectedPy2, self.fixture.simple({'alpha' : ['beta']}, [{'gamma'}]))
+      except AssertionError:
+        self.assertEqual(expectedPy3, self.fixture.simple({'alpha' : ['beta']}, [{'gamma'}]))
+        
       self.assertEqual(2, self.fixture.calls)
       self.assertEqual(1, self.getSize())
-  
-      self.assertEqual(expected, pickle.loads(self.testee.backend.client.get(key)))
+      
+      try:
+        self.assertEqual(expectedPy2, pickle.loads(self.testee.backend.client.get(key)))
+      except AssertionError:
+        self.assertEqual(expectedPy3, pickle.loads(self.testee.backend.client.get(key)))
     
   def testTagged(self):
     self.assertEqual(0, self.fixture.calls)
     self.assertEqual(0, self.getSize())
     
     for _ in range(4):    
-      self.assertEqual('ae-hl', self.fixture.tagged('alpha', 'beta'))
+      self.assertEqual('ae-hl', self.fixture.tagged('alpha', b = 'beta'))
       self.assertEqual(1,       self.fixture.calls)
       self.assertEqual(3,       self.getSize())
       
@@ -65,11 +73,12 @@ class TestMemcached(test.TestCase):
       self.assertEqual(16, len(rockTag))
       self.assertEqual(16, len(treeTag))
       
+      argHash = self._arghash('alpha', b = 'beta')
       tagHash = self.testee.mangler.hashTags(dict(tree = treeTag, rock = rockTag))
-      key     = 'cache:entry:Fixture:tagged:109cc9a8853ebcb1:' + tagHash
+      key     = 'cache:entry:Fixture:tagged:{0}:{1}'.format(argHash, tagHash)
       self.assertEqual('ae-hl', pickle.loads(self.testee.backend.client.get(key)))
     
-    self.fixture.tagged.invalidate('alpha', 'beta')
+    self.fixture.tagged.invalidate('alpha', b = 'beta')
     
     self.assertEqual(2, self.getSize())
     
@@ -124,7 +133,7 @@ class TestMemcached(test.TestCase):
     self.assertEqual(0, counter['foo'])
     self.assertEqual(0, self.getSize())
     
-    key = 'cache:entry:foo:109cc9a8853ebcb1'
+    key = 'cache:entry:foo:' + self._arghash('alpha', 'beta')
     for _ in range(4):
       self.assertEqual('ateb+ahpla', foo('alpha', 'beta'))
       
@@ -248,7 +257,7 @@ class TestMemcached(test.TestCase):
     self.assertEqual(2,            self.fixture.calls)
     self.assertEqual(4,            self.getSize())
 
-    simpleKey = 'cache:entry:Fixture:simple:109cc9a8853ebcb1'
+    simpleKey = 'cache:entry:Fixture:simple:' + self._arghash('alpha', 'beta')
     self.assertEqual('ateb+ahpla', pickle.loads(self.testee.backend.client.get(simpleKey)))
     
     rockTag = pickle.loads(self.testee.backend.client.get('cache:tag:rock'))
@@ -257,8 +266,9 @@ class TestMemcached(test.TestCase):
     self.assertEqual(16, len(rockTag))
     self.assertEqual(16, len(treeTag))
     
+    argHash   = self._arghash('gamma', 'delta')
     tagHash   = self.testee.mangler.hashTags(dict(tree = treeTag, rock = rockTag))
-    taggedKey = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb:' + tagHash
+    taggedKey = 'cache:entry:Fixture:tagged:{0}:{1}'.format(argHash, tagHash)
     self.assertEqual('aldamg', pickle.loads(self.testee.backend.client.get(taggedKey)))
     
     
@@ -290,8 +300,9 @@ class TestMemcached(test.TestCase):
     # stale still accessible, though only directly
     self.assertEqual('aldamg', pickle.loads(self.testee.backend.client.get(taggedKey)))
     
+    argHash   = self._arghash('gamma', 'delta')
     tagHash   = self.testee.mangler.hashTags(dict(tree = treeTag, rock = rockTag))
-    taggedKey = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb:' + tagHash
+    taggedKey = 'cache:entry:Fixture:tagged:{0}:{1}'.format(argHash, tagHash)
     self.assertEqual('aldamg', pickle.loads(self.testee.backend.client.get(taggedKey)))
     
     
@@ -323,8 +334,9 @@ class TestMemcached(test.TestCase):
     self.assertEqual(16, len(rockTag))
     self.assertEqual(16, len(treeTag))
     
+    argHash   = self._arghash('gamma', 'delta')
     tagHash   = self.testee.mangler.hashTags(dict(tree = treeTag, rock = rockTag))
-    taggedKey = 'cache:entry:Fixture:tagged:57f6833d90ca8fcb:' + tagHash
+    taggedKey = 'cache:entry:Fixture:tagged:{0}:{1}'.format(argHash, tagHash)
     self.assertEqual('aldamg', pickle.loads(self.testee.backend.client.get(taggedKey)))
     
     
@@ -335,9 +347,9 @@ class TestMemcached(test.TestCase):
   def testNested(self):
     self.assertEqual('beta+alpha', self.fixture.nested('alpha', 'beta'))
     self.assertEqual(2, self.fixture.calls)
-    key = 'cache:entry:Fixture:nested:109cc9a8853ebcb1'
+    key = 'cache:entry:Fixture:nested:' + self._arghash('alpha', 'beta')
     self.assertEqual('beta+alpha', pickle.loads(self.testee.backend.client.get(key)))
-    key = 'cache:entry:Fixture:simple:304d56b9ab021ab2'
+    key = 'cache:entry:Fixture:simple:' + self._arghash('beta', 'alpha')
     self.assertEqual('ahpla+ateb', pickle.loads(self.testee.backend.client.get(key)))  
     
   def testConcurrent(self):
@@ -349,9 +361,9 @@ class TestMemcached(test.TestCase):
       time.sleep(0.04)
       return '{0}-{1}'.format(a, b)[::2]
     
-    threads = map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertEqual(1, sum(log))
     self.assertEqual(3, self.getSize())
@@ -371,9 +383,9 @@ class TestMemcached(test.TestCase):
     self.testee.clean()
     self.testee.backend.lock = lambda k: hermes.backend.AbstractLock(k) # now see a dogpile 
     
-    threads = map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = bar, args = ('alpha', 'beta')), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertGreater(sum(log), 1, 'dogpile')
     # enries may be duplicated if tags overwrite
@@ -441,8 +453,9 @@ class TestMemcachedLock(test.TestCase):
         check.release()
         time.sleep(0.05)
     
-    threads = map(lambda i: threading.Thread(target = target), range(4))
-    map(threading.Thread.start, threads)
-    map(threading.Thread.join,  threads)
+    threads = tuple(map(lambda i: threading.Thread(target = target), range(4)))
+    tuple(map(threading.Thread.start, threads))
+    tuple(map(threading.Thread.join,  threads))
     
     self.assertEqual([True] * 4, log)
+
